@@ -101,6 +101,13 @@ defmodule Regex do
     * `:ungreedy` (U) - inverts the "greediness" of the regexp
       (the previous `r` option is deprecated in favor of `U`)
 
+    * `:export` (E) (since Elixir 1.20) - uses an exported pattern
+      which can be shared across nodes or through config, at the cost of a runtime
+      overhead every time to re-import it every time it is executed.
+      This modifier only has an effect starting on Erlang/OTP 28, and it is ignored
+      on older versions (i.e. `~r/foo/E == ~r/foo/`). This is because patterns cannot
+      and do not need to be exported in order to be shared in these versions.
+
   ## Captures
 
   Many functions in this module handle what to capture in a regex
@@ -251,7 +258,7 @@ defmodule Regex do
   This checks the version stored in the regular expression
   and recompiles the regex in case of version mismatch.
   """
-  # Remove me on Elixir v1.22
+  # TODO: Deprecate on Elixir v1.22
   @doc deprecated: "It can be removed and it has no effect"
   @doc since: "1.4.0"
   def recompile(%Regex{} = regex) do
@@ -261,7 +268,7 @@ defmodule Regex do
   @doc """
   Recompiles the existing regular expression and raises `Regex.CompileError` in case of errors.
   """
-  # Remove me on Elixir v1.22
+  # TODO: Deprecate on Elixir v1.22
   @doc deprecated: "It can be removed and it has no effect"
   @doc since: "1.4.0"
   def recompile!(regex) do
@@ -271,7 +278,7 @@ defmodule Regex do
   @doc """
   Returns the version of the underlying Regex engine.
   """
-  # Remove me on Elixir v1.22
+  # TODO: Deprecate on Elixir v1.22
   @doc deprecated: "Use :re.version() instead"
   @doc since: "1.4.0"
   def version do
@@ -515,7 +522,7 @@ defmodule Regex do
   """
   @spec names(t) :: [String.t()]
   def names(%Regex{re_pattern: re_pattern}) do
-    {:namelist, names} = :re.inspect(re_pattern, :namelist)
+    {:namelist, names} = :re.inspect(maybe_import_pattern(re_pattern), :namelist)
     names
   end
 
@@ -585,10 +592,16 @@ defmodule Regex do
       %Regex{source: source, opts: compile_opts} = regex
       :re.run(string, source, compile_opts ++ options)
     else
-      _ -> :re.run(string, re_pattern, options)
+      _ -> :re.run(string, maybe_import_pattern(re_pattern), options)
     end
   end
 
+  @compile {:inline, maybe_import_pattern: 1}
+  defp maybe_import_pattern({:re_exported_pattern, _, _, _, _} = exported),
+    do: :re.import(exported)
+
+  defp maybe_import_pattern(pattern), do: pattern
+
   @typedoc """
   Options for regex functions that capture matches.
   """
@@ -1007,6 +1020,16 @@ defmodule Regex do
     translate_options(t, [:ungreedy | acc])
   end
 
+  defp translate_options(<<?E, t::binary>>, acc) do
+    # on OTP 27-, the E modifier is a no-op since the feature doesn't exist but isn't needed
+    # (regexes aren't using references and can be shared across nodes or stored in config)
+    # TODO: remove this check on Erlang/OTP 28+ and update docs
+    case Code.ensure_loaded?(:re) and function_exported?(:re, :import, 1) do
+      true -> translate_options(t, [:export | acc])
+      false -> translate_options(t, acc)
+    end
+  end
+
   defp translate_options(<<>>, acc), do: acc
   defp translate_options(t, _acc), do: {:error, t}
 
@@ -1022,6 +1045,9 @@ defmodule Regex do
         :erlang.system_info(:otp_release) < [?2, ?8] ->
           Macro.escape(regex.re_pattern)
 
+        :lists.member(:export, regex.opts) ->
+          Macro.escape(regex.re_pattern)
+
         # OTP 28.1+ introduced the ability to export and import regexes from compiled binaries
         Code.ensure_loaded?(:re) and function_exported?(:re, :import, 1) ->
           {:ok, exported} = :re.compile(regex.source, [:export] ++ regex.opts)
