@@ -338,7 +338,8 @@ defmodule ExUnit.Formatter do
         {formatted_reason, wrapped_stack} =
           format_exception(test, struct, wrapped_stack, width, formatter, @counter_padding)
 
-        formatted_stack = format_stacktrace(wrapped_stack, test.module, test.name, formatter)
+        formatted_stack = format_stacktrace(wrapped_stack, test, formatter)
+
         {error_info(header, formatter) <> pad(formatted_reason <> formatted_stack), stack}
 
       :error ->
@@ -672,22 +673,28 @@ defmodule ExUnit.Formatter do
     |> Algebra.format(width)
   end
 
-  defp format_stacktrace([], _case, _test, _color) do
+  defp format_stacktrace(stack, %{module: module, name: name}, color),
+    do: format_stacktrace(stack, module, name, color)
+
+  defp format_stacktrace(stack, %{name: name}, color),
+    do: format_stacktrace(stack, name, nil, color)
+
+  defp format_stacktrace([], _module, _test, _color) do
     ""
   end
 
-  defp format_stacktrace(stacktrace, test_case, test, color) do
+  defp format_stacktrace(stacktrace, module, test, color) do
     extra_info("stacktrace:", color) <>
       Enum.map_join(stacktrace, fn entry ->
-        stacktrace_info(format_stacktrace_entry(entry, test_case, test), color)
+        stacktrace_info(format_stacktrace_entry(entry, module, test), color)
       end)
   end
 
-  defp format_stacktrace_entry({test_case, test, _, location}, test_case, test) do
+  defp format_stacktrace_entry({module, test, _, location}, module, test) do
     format_file_line(location[:file], location[:line], " (test)")
   end
 
-  defp format_stacktrace_entry(entry, _test_case, _test) do
+  defp format_stacktrace_entry(entry, _module, _test) do
     format_stacktrace_entry(entry)
   end
 
